Class: Tremendous::BalanceTransaction
- Inherits:
-
Object
- Object
- Tremendous::BalanceTransaction
- Defined in:
- lib/tremendous/models/balance_transaction.rb
Overview
A balance transaction represents a specific movement or change in an account’s balance.
Instance Attribute Summary collapse
-
#action ⇒ Object
The action that was performed.
-
#amount ⇒ Object
Amount of the transaction, denominated in ‘currency_code`.
-
#balance ⇒ Object
The updated total after the transaction, denominated in ‘currency_code`.
-
#created_at ⇒ Object
Date that the transaction was created.
-
#currency_code ⇒ Object
Currency of the transaction amount and running balance.
-
#description ⇒ Object
A brief description of the transaction.
-
#order ⇒ Object
Returns the value of attribute order.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BalanceTransaction
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ BalanceTransaction
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/tremendous/models/balance_transaction.rb', line 83 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Tremendous::BalanceTransaction` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Tremendous::BalanceTransaction`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'amount') self.amount = attributes[:'amount'] else self.amount = nil end if attributes.key?(:'currency_code') self.currency_code = attributes[:'currency_code'] else self.currency_code = nil end if attributes.key?(:'balance') self.balance = attributes[:'balance'] else self.balance = nil end if attributes.key?(:'action') self.action = attributes[:'action'] else self.action = nil end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = nil end if attributes.key?(:'order') self.order = attributes[:'order'] end end |
Instance Attribute Details
#action ⇒ Object
The action that was performed
32 33 34 |
# File 'lib/tremendous/models/balance_transaction.rb', line 32 def action @action end |
#amount ⇒ Object
Amount of the transaction, denominated in ‘currency_code`.
23 24 25 |
# File 'lib/tremendous/models/balance_transaction.rb', line 23 def amount @amount end |
#balance ⇒ Object
The updated total after the transaction, denominated in ‘currency_code`. Note that this running balance may be delayed and contain `null`.
29 30 31 |
# File 'lib/tremendous/models/balance_transaction.rb', line 29 def balance @balance end |
#created_at ⇒ Object
Date that the transaction was created
20 21 22 |
# File 'lib/tremendous/models/balance_transaction.rb', line 20 def created_at @created_at end |
#currency_code ⇒ Object
Currency of the transaction amount and running balance. Always matches the organization’s currency.
26 27 28 |
# File 'lib/tremendous/models/balance_transaction.rb', line 26 def currency_code @currency_code end |
#description ⇒ Object
A brief description of the transaction
35 36 37 |
# File 'lib/tremendous/models/balance_transaction.rb', line 35 def description @description end |
#order ⇒ Object
Returns the value of attribute order.
37 38 39 |
# File 'lib/tremendous/models/balance_transaction.rb', line 37 def order @order end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/tremendous/models/balance_transaction.rb', line 296 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Tremendous.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/tremendous/models/balance_transaction.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/tremendous/models/balance_transaction.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/tremendous/models/balance_transaction.rb', line 40 def self.attribute_map { :'created_at' => :'created_at', :'amount' => :'amount', :'currency_code' => :'currency_code', :'balance' => :'balance', :'action' => :'action', :'description' => :'description', :'order' => :'order' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/tremendous/models/balance_transaction.rb', line 272 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
76 77 78 79 |
# File 'lib/tremendous/models/balance_transaction.rb', line 76 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/tremendous/models/balance_transaction.rb', line 63 def self.openapi_types { :'created_at' => :'Time', :'amount' => :'Float', :'currency_code' => :'String', :'balance' => :'Float', :'action' => :'String', :'description' => :'String', :'order' => :'BalanceTransactionOrder' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/tremendous/models/balance_transaction.rb', line 245 def ==(o) return true if self.equal?(o) self.class == o.class && created_at == o.created_at && amount == o.amount && currency_code == o.currency_code && balance == o.balance && action == o.action && description == o.description && order == o.order end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/tremendous/models/balance_transaction.rb', line 367 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
259 260 261 |
# File 'lib/tremendous/models/balance_transaction.rb', line 259 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
265 266 267 |
# File 'lib/tremendous/models/balance_transaction.rb', line 265 def hash [created_at, amount, currency_code, balance, action, description, order].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/tremendous/models/balance_transaction.rb', line 140 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @amount.nil? invalid_properties.push('invalid value for "amount", amount cannot be nil.') end if @currency_code.nil? invalid_properties.push('invalid value for "currency_code", currency_code cannot be nil.') end if @balance.nil? invalid_properties.push('invalid value for "balance", balance cannot be nil.') end if @action.nil? invalid_properties.push('invalid value for "action", action cannot be nil.') end if @description.nil? invalid_properties.push('invalid value for "description", description cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
343 344 345 |
# File 'lib/tremendous/models/balance_transaction.rb', line 343 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/tremendous/models/balance_transaction.rb', line 349 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
337 338 339 |
# File 'lib/tremendous/models/balance_transaction.rb', line 337 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
172 173 174 175 176 177 178 179 180 181 |
# File 'lib/tremendous/models/balance_transaction.rb', line 172 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @created_at.nil? return false if @amount.nil? return false if @currency_code.nil? return false if @balance.nil? return false if @action.nil? return false if @description.nil? true end |