Class: Tremendous::Configuration
- Inherits:
-
Object
- Object
- Tremendous::Configuration
- Defined in:
- lib/tremendous/configuration.rb
Constant Summary collapse
- Environment =
Tremendous Environment mapping
{ "testflight" => 0, "production" => 1 }
Instance Attribute Summary collapse
-
#access_token ⇒ Object
Defines the access token (Bearer) used with OAuth2.
-
#access_token_getter ⇒ Proc
Defines a Proc used to fetch or refresh access tokens (Bearer) used with OAuth2.
-
#api_key ⇒ Hash
Defines API keys used with API Key authentications.
-
#api_key_prefix ⇒ Hash
Defines API key prefixes used with API Key authentications.
-
#base_path ⇒ Object
Defines url base path.
-
#client_side_validation ⇒ true, false
Set this to false to skip client side validation in the operation.
-
#debugging ⇒ true, false
Set this to enable/disable debugging.
-
#force_ending_format ⇒ Object
Returns the value of attribute force_ending_format.
-
#host ⇒ Object
Defines url host.
-
#ignore_operation_servers ⇒ true, false
Set this to ignore operation servers for the API client.
-
#inject_format ⇒ Object
Returns the value of attribute inject_format.
-
#logger ⇒ #debug
Defines the logger used for debugging.
-
#params_encoder ⇒ Object
Set this to customize parameters encoder of array parameter.
-
#password ⇒ String
Defines the password used with HTTP basic authentication.
-
#proxy ⇒ Object
Proxy setting HTTP Proxy settings.
-
#return_binary_data ⇒ Object
Set this to return data as binary instead of downloading a temp file.
-
#scheme ⇒ Object
Defines url scheme.
-
#server_index ⇒ Object
Define server configuration index.
-
#server_operation_index ⇒ Object
Define server operation configuration index.
-
#server_operation_variables ⇒ Object
Default server operation variables.
-
#server_variables ⇒ Object
Default server variables.
-
#ssl_ca_file ⇒ String
TLS/SSL setting Set this to customize the certificate file to verify the peer.
-
#ssl_client_cert ⇒ Object
TLS/SSL setting Client certificate file (for client certificate).
-
#ssl_client_key ⇒ Object
TLS/SSL setting Client private key file (for client certificate).
-
#ssl_verify ⇒ true, false
TLS/SSL setting Set this to false to skip verifying SSL certificate when calling API from https server.
-
#ssl_verify_mode ⇒ Object
TLS/SSL setting Any
OpenSSL::SSL::constant (see https://ruby-doc.org/stdlib-2.5.1/libdoc/openssl/rdoc/OpenSSL/SSL.html). -
#temp_folder_path ⇒ String
Defines the temporary folder to store downloaded files (for API endpoints that have file response).
-
#timeout ⇒ Object
The time limit for HTTP request in seconds.
-
#username ⇒ String
Defines the username used with HTTP basic authentication.
Class Method Summary collapse
-
.default ⇒ Object
The default Configuration object.
Instance Method Summary collapse
-
#access_token_with_refresh ⇒ Object
Gets access_token using access_token_getter or uses the static access_token.
-
#api_key_with_prefix(param_name, param_alias = nil) ⇒ Object
Gets API key (with prefix if set).
-
#auth_settings ⇒ Object
Returns Auth Settings hash for api client.
-
#base_url(operation = nil) ⇒ Object
Returns base URL for specified operation based on server settings.
-
#basic_auth_token ⇒ Object
Gets Basic Auth token string.
- #configure {|_self| ... } ⇒ Object
- #configure_connection(conn) ⇒ Object
-
#configure_faraday_connection(&block) ⇒ Object
Configure Faraday connection directly.
-
#configure_middleware(connection) ⇒ Object
Set up middleware on the connection.
-
#initialize {|_self| ... } ⇒ Configuration
constructor
A new instance of Configuration.
- #operation_server_settings ⇒ Object
-
#request(*middleware) ⇒ Object
Adds request middleware to the stack.
-
#response(*middleware) ⇒ Object
Adds response middleware to the stack.
-
#server_settings ⇒ Object
Returns an array of Server setting.
-
#server_url(index, variables = {}, servers = nil) ⇒ Object
Returns URL based on server settings.
-
#set_faraday_middleware(operation, key, *args, &block) ⇒ Object
Adds Faraday middleware setting information to the stack.
-
#use(*middleware) ⇒ Object
Adds middleware to the stack.
Constructor Details
#initialize {|_self| ... } ⇒ Configuration
Returns a new instance of Configuration.
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/tremendous/configuration.rb', line 161 def initialize @scheme = 'https' @host = 'testflight.tremendous.com' @base_path = '/api/v2' @server_index = nil @server_operation_index = {} @server_variables = {} @server_operation_variables = {} @api_key = {} @api_key_prefix = {} @client_side_validation = true @ssl_verify = true @ssl_verify_mode = nil @ssl_ca_file = nil @ssl_client_cert = nil @ssl_client_key = nil @middlewares = Hash.new { |h, k| h[k] = [] } @configure_connection_blocks = [] @timeout = 60 # return data as binary instead of file @return_binary_data = false @params_encoder = nil @debugging = false @ignore_operation_servers = false @inject_format = false @force_ending_format = false @logger = defined?(Rails) ? Rails.logger : Logger.new(STDOUT) yield(self) if block_given? end |
Instance Attribute Details
#access_token ⇒ Object
Defines the access token (Bearer) used with OAuth2.
66 67 68 |
# File 'lib/tremendous/configuration.rb', line 66 def access_token @access_token end |
#access_token_getter ⇒ Proc
Defines a Proc used to fetch or refresh access tokens (Bearer) used with OAuth2. Overrides the access_token if set
71 72 73 |
# File 'lib/tremendous/configuration.rb', line 71 def access_token_getter @access_token_getter end |
#api_key ⇒ Hash
Defines API keys used with API Key authentications.
45 46 47 |
# File 'lib/tremendous/configuration.rb', line 45 def api_key @api_key end |
#api_key_prefix ⇒ Hash
Defines API key prefixes used with API Key authentications.
53 54 55 |
# File 'lib/tremendous/configuration.rb', line 53 def api_key_prefix @api_key_prefix end |
#base_path ⇒ Object
Defines url base path
25 26 27 |
# File 'lib/tremendous/configuration.rb', line 25 def base_path @base_path end |
#client_side_validation ⇒ true, false
Set this to false to skip client side validation in the operation. Default to true.
113 114 115 |
# File 'lib/tremendous/configuration.rb', line 113 def client_side_validation @client_side_validation end |
#debugging ⇒ true, false
Set this to enable/disable debugging. When enabled (set to true), HTTP request/response
details will be logged with logger.debug (see the logger attribute).
Default to false.
83 84 85 |
# File 'lib/tremendous/configuration.rb', line 83 def debugging @debugging end |
#force_ending_format ⇒ Object
Returns the value of attribute force_ending_format.
159 160 161 |
# File 'lib/tremendous/configuration.rb', line 159 def force_ending_format @force_ending_format end |
#host ⇒ Object
Defines url host
22 23 24 |
# File 'lib/tremendous/configuration.rb', line 22 def host @host end |
#ignore_operation_servers ⇒ true, false
Set this to ignore operation servers for the API client. This is useful when you need to
send requests to a different server than the one specified in the OpenAPI document.
Will default to the base url defined in the spec but can be overridden by setting
scheme, host, base_path directly.
Default to false.
91 92 93 |
# File 'lib/tremendous/configuration.rb', line 91 def ignore_operation_servers @ignore_operation_servers end |
#inject_format ⇒ Object
Returns the value of attribute inject_format.
157 158 159 |
# File 'lib/tremendous/configuration.rb', line 157 def inject_format @inject_format end |
#logger ⇒ #debug
Defines the logger used for debugging.
Default to Rails.logger (when in Rails) or logging to STDOUT.
97 98 99 |
# File 'lib/tremendous/configuration.rb', line 97 def logger @logger end |
#params_encoder ⇒ Object
Set this to customize parameters encoder of array parameter. Default to nil. Faraday uses NestedParamsEncoder when nil.
https://github.com/lostisland/faraday/tree/main/lib/faraday/encoders
154 155 156 |
# File 'lib/tremendous/configuration.rb', line 154 def params_encoder @params_encoder end |
#password ⇒ String
Defines the password used with HTTP basic authentication.
63 64 65 |
# File 'lib/tremendous/configuration.rb', line 63 def password @password end |
#proxy ⇒ Object
Proxy setting HTTP Proxy settings
147 148 149 |
# File 'lib/tremendous/configuration.rb', line 147 def proxy @proxy end |
#return_binary_data ⇒ Object
Set this to return data as binary instead of downloading a temp file. When enabled (set to true)
HTTP responses with return type File will be returned as a stream of binary data.
Default to false.
76 77 78 |
# File 'lib/tremendous/configuration.rb', line 76 def return_binary_data @return_binary_data end |
#scheme ⇒ Object
Defines url scheme
19 20 21 |
# File 'lib/tremendous/configuration.rb', line 19 def scheme @scheme end |
#server_index ⇒ Object
Define server configuration index
28 29 30 |
# File 'lib/tremendous/configuration.rb', line 28 def server_index @server_index end |
#server_operation_index ⇒ Object
Define server operation configuration index
31 32 33 |
# File 'lib/tremendous/configuration.rb', line 31 def server_operation_index @server_operation_index end |
#server_operation_variables ⇒ Object
Default server operation variables
37 38 39 |
# File 'lib/tremendous/configuration.rb', line 37 def server_operation_variables @server_operation_variables end |
#server_variables ⇒ Object
Default server variables
34 35 36 |
# File 'lib/tremendous/configuration.rb', line 34 def server_variables @server_variables end |
#ssl_ca_file ⇒ String
TLS/SSL setting Set this to customize the certificate file to verify the peer.
135 136 137 |
# File 'lib/tremendous/configuration.rb', line 135 def ssl_ca_file @ssl_ca_file end |
#ssl_client_cert ⇒ Object
TLS/SSL setting Client certificate file (for client certificate)
139 140 141 |
# File 'lib/tremendous/configuration.rb', line 139 def ssl_client_cert @ssl_client_cert end |
#ssl_client_key ⇒ Object
TLS/SSL setting Client private key file (for client certificate)
143 144 145 |
# File 'lib/tremendous/configuration.rb', line 143 def ssl_client_key @ssl_client_key end |
#ssl_verify ⇒ true, false
Do NOT set it to false in production code, otherwise you would face multiple types of cryptographic attacks.
TLS/SSL setting Set this to false to skip verifying SSL certificate when calling API from https server. Default to true.
122 123 124 |
# File 'lib/tremendous/configuration.rb', line 122 def ssl_verify @ssl_verify end |
#ssl_verify_mode ⇒ Object
Do NOT set it to false in production code, otherwise you would face multiple types of cryptographic attacks.
TLS/SSL setting
Any OpenSSL::SSL:: constant (see https://ruby-doc.org/stdlib-2.5.1/libdoc/openssl/rdoc/OpenSSL/SSL.html)
129 130 131 |
# File 'lib/tremendous/configuration.rb', line 129 def ssl_verify_mode @ssl_verify_mode end |
#temp_folder_path ⇒ String
Defines the temporary folder to store downloaded files
(for API endpoints that have file response).
Default to use Tempfile.
104 105 106 |
# File 'lib/tremendous/configuration.rb', line 104 def temp_folder_path @temp_folder_path end |
#timeout ⇒ Object
The time limit for HTTP request in seconds. Default to 0 (never times out).
108 109 110 |
# File 'lib/tremendous/configuration.rb', line 108 def timeout @timeout end |
#username ⇒ String
Defines the username used with HTTP basic authentication.
58 59 60 |
# File 'lib/tremendous/configuration.rb', line 58 def username @username end |
Class Method Details
.default ⇒ Object
The default Configuration object.
193 194 195 |
# File 'lib/tremendous/configuration.rb', line 193 def self.default @@default ||= Configuration.new end |
Instance Method Details
#access_token_with_refresh ⇒ Object
Gets access_token using access_token_getter or uses the static access_token
241 242 243 244 |
# File 'lib/tremendous/configuration.rb', line 241 def access_token_with_refresh return access_token if access_token_getter.nil? access_token_getter.call end |
#api_key_with_prefix(param_name, param_alias = nil) ⇒ Object
Gets API key (with prefix if set).
230 231 232 233 234 235 236 237 238 |
# File 'lib/tremendous/configuration.rb', line 230 def api_key_with_prefix(param_name, param_alias = nil) key = @api_key[param_name] key = @api_key.fetch(param_alias, key) unless param_alias.nil? if @api_key_prefix[param_name] "#{@api_key_prefix[param_name]} #{key}" else key end end |
#auth_settings ⇒ Object
Returns Auth Settings hash for api client.
252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/tremendous/configuration.rb', line 252 def auth_settings { 'BearerApiKey' => { type: 'bearer', in: 'header', key: 'Authorization', value: "Bearer #{access_token_with_refresh}" }, } end |
#base_url(operation = nil) ⇒ Object
Returns base URL for specified operation based on server settings
218 219 220 221 222 223 224 225 226 |
# File 'lib/tremendous/configuration.rb', line 218 def base_url(operation = nil) return "#{scheme}://#{[host, base_path].join('/').gsub(/\/+/, '/')}".sub(/\/+\z/, '') if ignore_operation_servers if operation_server_settings.key?(operation) then index = server_operation_index.fetch(operation, server_index) server_url(index.nil? ? 0 : index, server_operation_variables.fetch(operation, server_variables), operation_server_settings[operation]) else server_index.nil? ? "#{scheme}://#{[host, base_path].join('/').gsub(/\/+/, '/')}".sub(/\/+\z/, '') : server_url(server_index, server_variables, nil) end end |
#basic_auth_token ⇒ Object
Gets Basic Auth token string
247 248 249 |
# File 'lib/tremendous/configuration.rb', line 247 def basic_auth_token 'Basic ' + ["#{username}:#{password}"].pack('m').delete("\r\n") end |
#configure {|_self| ... } ⇒ Object
197 198 199 |
# File 'lib/tremendous/configuration.rb', line 197 def configure yield(self) if block_given? end |
#configure_connection(conn) ⇒ Object
337 338 339 340 341 |
# File 'lib/tremendous/configuration.rb', line 337 def configure_connection(conn) @configure_connection_blocks.each do |block| block.call(conn) end end |
#configure_faraday_connection(&block) ⇒ Object
Configure Faraday connection directly.
c.configure_faraday_connection do |conn|
conn.use Faraday::HttpCache, shared_cache: false, logger: logger
conn.response :logger, nil, headers: true, bodies: true, log_level: :debug do |logger|
logger.filter(/(Authorization: )(.*)/, '\1[REDACTED]')
end
end
c.configure_faraday_connection do |conn|
conn.adapter :typhoeus
end
333 334 335 |
# File 'lib/tremendous/configuration.rb', line 333 def configure_faraday_connection(&block) @configure_connection_blocks << block end |
#configure_middleware(connection) ⇒ Object
Set up middleware on the connection
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/tremendous/configuration.rb', line 380 def configure_middleware(connection) return if @middlewares.empty? [:request, :response, :use, :insert, :insert_before, :insert_after, :swap].each do |operation| next unless @middlewares.key?(operation) @middlewares[operation].each do |key, args, block| connection.builder.send(operation, key, *args, &block) end end if @middlewares.key?(:delete) @middlewares[:delete].each do |key, _args, _block| connection.builder.delete(key) end end end |
#operation_server_settings ⇒ Object
278 279 280 281 |
# File 'lib/tremendous/configuration.rb', line 278 def operation_server_settings { } end |
#request(*middleware) ⇒ Object
Adds request middleware to the stack
349 350 351 |
# File 'lib/tremendous/configuration.rb', line 349 def request(*middleware) set_faraday_middleware(:request, *middleware) end |
#response(*middleware) ⇒ Object
Adds response middleware to the stack
354 355 356 |
# File 'lib/tremendous/configuration.rb', line 354 def response(*middleware) set_faraday_middleware(:response, *middleware) end |
#server_settings ⇒ Object
Returns an array of Server setting
265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/tremendous/configuration.rb', line 265 def server_settings [ { url: "https://testflight.tremendous.com/api/v2", description: "Sandbox environment", }, { url: "https://api.tremendous.com/api/v2", description: "Production environment", } ] end |
#server_url(index, variables = {}, servers = nil) ⇒ Object
Returns URL based on server settings
287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/tremendous/configuration.rb', line 287 def server_url(index, variables = {}, servers = nil) servers = server_settings if servers == nil # check array index out of bound if (index.nil? || index < 0 || index >= servers.size) fail ArgumentError, "Invalid index #{index} when selecting the server. Must not be nil and must be less than #{servers.size}" end server = servers[index] url = server[:url] return url unless server.key? :variables # go through variable and assign a value server[:variables].each do |name, variable| if variables.key?(name) if (!server[:variables][name].key?(:enum_values) || server[:variables][name][:enum_values].include?(variables[name])) url.gsub! "{" + name.to_s + "}", variables[name] else fail ArgumentError, "The variable `#{name}` in the server URL has invalid value #{variables[name]}. Must be #{server[:variables][name][:enum_values]}." end else # use default value url.gsub! "{" + name.to_s + "}", server[:variables][name][:default_value] end end url end |
#set_faraday_middleware(operation, key, *args, &block) ⇒ Object
Adds Faraday middleware setting information to the stack
369 370 371 372 373 374 375 376 |
# File 'lib/tremendous/configuration.rb', line 369 def set_faraday_middleware(operation, key, *args, &block) unless [:request, :response, :use, :insert, :insert_before, :insert_after, :swap, :delete].include?(operation) fail ArgumentError, "Invalid faraday middleware operation #{operation}. Must be" \ " :request, :response, :use, :insert, :insert_before, :insert_after, :swap or :delete." end @middlewares[operation] << [key, args, block] end |
#use(*middleware) ⇒ Object
Adds middleware to the stack
344 345 346 |
# File 'lib/tremendous/configuration.rb', line 344 def use(*middleware) set_faraday_middleware(:use, *middleware) end |