Class: Tremendous::CreateOrganization200ResponseOrganization

Inherits:
Object
  • Object
show all
Defined in:
lib/tremendous/models/create_organization200_response_organization.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateOrganization200ResponseOrganization

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/tremendous/models/create_organization200_response_organization.rb', line 82

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Tremendous::CreateOrganization200ResponseOrganization` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Tremendous::CreateOrganization200ResponseOrganization`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'website')
    self.website = attributes[:'website']
  else
    self.website = nil
  end

  if attributes.key?(:'copy_settings')
    self.copy_settings = attributes[:'copy_settings']
  end

  if attributes.key?(:'phone')
    self.phone = attributes[:'phone']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'api_key')
    self.api_key = attributes[:'api_key']
  end
end

Instance Attribute Details

#api_keyObject

The API key for the created organization. This property is only returned when ‘api_key` is set to `true`.



35
36
37
# File 'lib/tremendous/models/create_organization200_response_organization.rb', line 35

def api_key
  @api_key
end

#copy_settingsObject

Returns the value of attribute copy_settings.



26
27
28
# File 'lib/tremendous/models/create_organization200_response_organization.rb', line 26

def copy_settings
  @copy_settings
end

#created_atObject

Timestamp of when the organization has been created.



32
33
34
# File 'lib/tremendous/models/create_organization200_response_organization.rb', line 32

def created_at
  @created_at
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/tremendous/models/create_organization200_response_organization.rb', line 18

def id
  @id
end

#nameObject

Name of the organization



21
22
23
# File 'lib/tremendous/models/create_organization200_response_organization.rb', line 21

def name
  @name
end

#phoneObject

Phone number of the organization. For non-US phone numbers, specify the country code (prefixed with +).



29
30
31
# File 'lib/tremendous/models/create_organization200_response_organization.rb', line 29

def phone
  @phone
end

#websiteObject

URL of the website of that organization



24
25
26
# File 'lib/tremendous/models/create_organization200_response_organization.rb', line 24

def website
  @website
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/tremendous/models/create_organization200_response_organization.rb', line 248

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Tremendous.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



51
52
53
# File 'lib/tremendous/models/create_organization200_response_organization.rb', line 51

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



56
57
58
# File 'lib/tremendous/models/create_organization200_response_organization.rb', line 56

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
# File 'lib/tremendous/models/create_organization200_response_organization.rb', line 38

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'website' => :'website',
    :'copy_settings' => :'copy_settings',
    :'phone' => :'phone',
    :'created_at' => :'created_at',
    :'api_key' => :'api_key'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/tremendous/models/create_organization200_response_organization.rb', line 224

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
78
# File 'lib/tremendous/models/create_organization200_response_organization.rb', line 74

def self.openapi_nullable
  Set.new([
    :'phone',
  ])
end

.openapi_typesObject

Attribute type mapping.



61
62
63
64
65
66
67
68
69
70
71
# File 'lib/tremendous/models/create_organization200_response_organization.rb', line 61

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'website' => :'String',
    :'copy_settings' => :'CreateOrganizationRequestCopySettings',
    :'phone' => :'String',
    :'created_at' => :'Date',
    :'api_key' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



197
198
199
200
201
202
203
204
205
206
207
# File 'lib/tremendous/models/create_organization200_response_organization.rb', line 197

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      website == o.website &&
      copy_settings == o.copy_settings &&
      phone == o.phone &&
      created_at == o.created_at &&
      api_key == o.api_key
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



319
320
321
322
323
324
325
326
327
328
329
330
331
# File 'lib/tremendous/models/create_organization200_response_organization.rb', line 319

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


211
212
213
# File 'lib/tremendous/models/create_organization200_response_organization.rb', line 211

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



217
218
219
# File 'lib/tremendous/models/create_organization200_response_organization.rb', line 217

def hash
  [id, name, website, copy_settings, phone, created_at, api_key].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/tremendous/models/create_organization200_response_organization.rb', line 131

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/[A-Z0-9]{4,20}/)
  if !@id.nil? && @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @website.nil?
    invalid_properties.push('invalid value for "website", website cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



295
296
297
# File 'lib/tremendous/models/create_organization200_response_organization.rb', line 295

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/tremendous/models/create_organization200_response_organization.rb', line 301

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



289
290
291
# File 'lib/tremendous/models/create_organization200_response_organization.rb', line 289

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



152
153
154
155
156
157
158
# File 'lib/tremendous/models/create_organization200_response_organization.rb', line 152

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@id.nil? && @id !~ Regexp.new(/[A-Z0-9]{4,20}/)
  return false if @name.nil?
  return false if @website.nil?
  true
end