Class: Tremendous::CreateOrganizationRequestCopySettings
- Inherits:
-
Object
- Object
- Tremendous::CreateOrganizationRequestCopySettings
- Defined in:
- lib/tremendous/models/create_organization_request_copy_settings.rb
Overview
A list of the settings that you wish to copy over to the new organization.
Instance Attribute Summary collapse
-
#campaigns ⇒ Object
Copy over the campaigns from the current organization to the new organization.
-
#custom_fields ⇒ Object
Copy over the custom fields from the current organization to the new organization.
-
#custom_roles ⇒ Object
Copy over the custom roles from the current organization to the new organization.
-
#fraud_prevention ⇒ Object
Copy over the fraud prevention settings and rules from the current organization to the new organization.
-
#order_approvals ⇒ Object
Copy over the order approvals settings from the current organization to the new organization.
-
#payment_methods ⇒ Object
Copy over the payment methods from the current organization to the new organization.
-
#security_settings ⇒ Object
Copy over the security settings from the current organization to the new organization.
-
#tax_management ⇒ Object
Copy over the tax management settings, including the association with the parent tax entity, from the current organization to the new organization.
-
#users ⇒ Object
Copy over the users and custom roles from the current organization to the new organization.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateOrganizationRequestCopySettings
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CreateOrganizationRequestCopySettings
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/tremendous/models/create_organization_request_copy_settings.rb', line 94 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Tremendous::CreateOrganizationRequestCopySettings` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Tremendous::CreateOrganizationRequestCopySettings`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'campaigns') self.campaigns = attributes[:'campaigns'] else self.campaigns = false end if attributes.key?(:'custom_fields') self.custom_fields = attributes[:'custom_fields'] else self.custom_fields = false end if attributes.key?(:'order_approvals') self.order_approvals = attributes[:'order_approvals'] else self.order_approvals = false end if attributes.key?(:'payment_methods') self.payment_methods = attributes[:'payment_methods'] else self.payment_methods = false end if attributes.key?(:'security_settings') self.security_settings = attributes[:'security_settings'] else self.security_settings = true end if attributes.key?(:'users') self.users = attributes[:'users'] else self.users = false end if attributes.key?(:'custom_roles') self.custom_roles = attributes[:'custom_roles'] else self.custom_roles = false end if attributes.key?(:'fraud_prevention') self.fraud_prevention = attributes[:'fraud_prevention'] else self.fraud_prevention = false end if attributes.key?(:'tax_management') self.tax_management = attributes[:'tax_management'] else self.tax_management = false end end |
Instance Attribute Details
#campaigns ⇒ Object
Copy over the campaigns from the current organization to the new organization. Defaults to ‘false`.
20 21 22 |
# File 'lib/tremendous/models/create_organization_request_copy_settings.rb', line 20 def campaigns @campaigns end |
#custom_fields ⇒ Object
Copy over the custom fields from the current organization to the new organization. Defaults to ‘false`.
23 24 25 |
# File 'lib/tremendous/models/create_organization_request_copy_settings.rb', line 23 def custom_fields @custom_fields end |
#custom_roles ⇒ Object
Copy over the custom roles from the current organization to the new organization. Custom roles are always copied if ‘users` is `true`. Defaults to `false`.
38 39 40 |
# File 'lib/tremendous/models/create_organization_request_copy_settings.rb', line 38 def custom_roles @custom_roles end |
#fraud_prevention ⇒ Object
Copy over the fraud prevention settings and rules from the current organization to the new organization. Defaults to ‘false`.
41 42 43 |
# File 'lib/tremendous/models/create_organization_request_copy_settings.rb', line 41 def fraud_prevention @fraud_prevention end |
#order_approvals ⇒ Object
Copy over the order approvals settings from the current organization to the new organization. Defaults to ‘false`.
26 27 28 |
# File 'lib/tremendous/models/create_organization_request_copy_settings.rb', line 26 def order_approvals @order_approvals end |
#payment_methods ⇒ Object
Copy over the payment methods from the current organization to the new organization. Defaults to ‘false`.
29 30 31 |
# File 'lib/tremendous/models/create_organization_request_copy_settings.rb', line 29 def payment_methods @payment_methods end |
#security_settings ⇒ Object
Copy over the security settings from the current organization to the new organization. Defaults to ‘true`.
32 33 34 |
# File 'lib/tremendous/models/create_organization_request_copy_settings.rb', line 32 def security_settings @security_settings end |
#tax_management ⇒ Object
Copy over the tax management settings, including the association with the parent tax entity, from the current organization to the new organization. Defaults to ‘false`.
44 45 46 |
# File 'lib/tremendous/models/create_organization_request_copy_settings.rb', line 44 def tax_management @tax_management end |
#users ⇒ Object
Copy over the users and custom roles from the current organization to the new organization. Defaults to ‘false`.
35 36 37 |
# File 'lib/tremendous/models/create_organization_request_copy_settings.rb', line 35 def users @users end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/tremendous/models/create_organization_request_copy_settings.rb', line 233 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Tremendous.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
62 63 64 |
# File 'lib/tremendous/models/create_organization_request_copy_settings.rb', line 62 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
67 68 69 |
# File 'lib/tremendous/models/create_organization_request_copy_settings.rb', line 67 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/tremendous/models/create_organization_request_copy_settings.rb', line 47 def self.attribute_map { :'campaigns' => :'campaigns', :'custom_fields' => :'custom_fields', :'order_approvals' => :'order_approvals', :'payment_methods' => :'payment_methods', :'security_settings' => :'security_settings', :'users' => :'users', :'custom_roles' => :'custom_roles', :'fraud_prevention' => :'fraud_prevention', :'tax_management' => :'tax_management' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/tremendous/models/create_organization_request_copy_settings.rb', line 209 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 |
# File 'lib/tremendous/models/create_organization_request_copy_settings.rb', line 87 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/tremendous/models/create_organization_request_copy_settings.rb', line 72 def self.openapi_types { :'campaigns' => :'Boolean', :'custom_fields' => :'Boolean', :'order_approvals' => :'Boolean', :'payment_methods' => :'Boolean', :'security_settings' => :'Boolean', :'users' => :'Boolean', :'custom_roles' => :'Boolean', :'fraud_prevention' => :'Boolean', :'tax_management' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/tremendous/models/create_organization_request_copy_settings.rb', line 180 def ==(o) return true if self.equal?(o) self.class == o.class && campaigns == o.campaigns && custom_fields == o.custom_fields && order_approvals == o.order_approvals && payment_methods == o.payment_methods && security_settings == o.security_settings && users == o.users && custom_roles == o.custom_roles && fraud_prevention == o.fraud_prevention && tax_management == o.tax_management end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/tremendous/models/create_organization_request_copy_settings.rb', line 304 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
196 197 198 |
# File 'lib/tremendous/models/create_organization_request_copy_settings.rb', line 196 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
202 203 204 |
# File 'lib/tremendous/models/create_organization_request_copy_settings.rb', line 202 def hash [campaigns, custom_fields, order_approvals, payment_methods, security_settings, users, custom_roles, fraud_prevention, tax_management].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
165 166 167 168 169 |
# File 'lib/tremendous/models/create_organization_request_copy_settings.rb', line 165 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
280 281 282 |
# File 'lib/tremendous/models/create_organization_request_copy_settings.rb', line 280 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/tremendous/models/create_organization_request_copy_settings.rb', line 286 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
274 275 276 |
# File 'lib/tremendous/models/create_organization_request_copy_settings.rb', line 274 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
173 174 175 176 |
# File 'lib/tremendous/models/create_organization_request_copy_settings.rb', line 173 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |