Class: Tremendous::FraudReview

Inherits:
Object
  • Object
show all
Defined in:
lib/tremendous/models/fraud_review.rb

Overview

The fraud review associated with a reward.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ FraudReview

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/tremendous/models/fraud_review.rb', line 128

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Tremendous::FraudReview` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Tremendous::FraudReview`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'reasons')
    if (value = attributes[:'reasons']).is_a?(Array)
      self.reasons = value
    end
  end

  if attributes.key?(:'device_id')
    self.device_id = attributes[:'device_id']
  end

  if attributes.key?(:'redemption_method')
    self.redemption_method = attributes[:'redemption_method']
  end

  if attributes.key?(:'redeemed_at')
    self.redeemed_at = attributes[:'redeemed_at']
  end

  if attributes.key?(:'geo')
    self.geo = attributes[:'geo']
  end

  if attributes.key?(:'reward')
    self.reward = attributes[:'reward']
  end

  if attributes.key?(:'reviewed_by')
    self.reviewed_by = attributes[:'reviewed_by']
  end

  if attributes.key?(:'reviewed_at')
    self.reviewed_at = attributes[:'reviewed_at']
  end

  if attributes.key?(:'redemption_method_account_hash')
    self. = attributes[:'redemption_method_account_hash']
  end

  if attributes.key?(:'risk')
    self.risk = attributes[:'risk']
  end

  if attributes.key?(:'related_rewards')
    self.related_rewards = attributes[:'related_rewards']
  end
end

Instance Attribute Details

#device_idObject

The device fingerprint, if known.



26
27
28
# File 'lib/tremendous/models/fraud_review.rb', line 26

def device_id
  @device_id
end

#geoObject

Returns the value of attribute geo.



34
35
36
# File 'lib/tremendous/models/fraud_review.rb', line 34

def geo
  @geo
end

#reasonsObject

The array may contain multiple reasons, depending on which rule(s) flagged the reward for review. Reasons can be any of the following: * ‘Disallowed IP` * `Disallowed email` * `Disallowed country` * `Over reward dollar limit` * `Over reward count limit` * `VPN detected` * `Device related to multiple emails` * `Device or account related to multiple emails` * `IP on a Tremendous fraud list` * `Bank account on a Tremendous fraud list` * `Fingerprint on a Tremendous fraud list` * `Email on a Tremendous fraud list` * `Phone on a Tremendous fraud list` * `IP related to a blocked reward` * `Device related to a blocked reward` * `Bank account related to a blocked reward` * `Fingerprint related to a blocked reward` * `Email related to a blocked reward` * `Phone related to a blocked reward` * `Allowed IP` * `Allowed email`



23
24
25
# File 'lib/tremendous/models/fraud_review.rb', line 23

def reasons
  @reasons
end

#redeemed_atObject

Date the reward was redeemed



32
33
34
# File 'lib/tremendous/models/fraud_review.rb', line 32

def redeemed_at
  @redeemed_at
end

#redemption_methodObject

The product selected to claim the reward



29
30
31
# File 'lib/tremendous/models/fraud_review.rb', line 29

def redemption_method
  @redemption_method
end

#redemption_method_account_hashObject

A hash of the destination account for redemption methods that require providing 3rd party account details (e.g., PayPal, Venmo, ACH/CashApp, international bank transfers, etc.). The hash is globally unique by redemption method + account combination. This field is omitted for redemption methods that don’t have a destination account (e.g., merchant cards, charities, etc.).



45
46
47
# File 'lib/tremendous/models/fraud_review.rb', line 45

def 
  @redemption_method_account_hash
end

Returns the value of attribute related_rewards.



50
51
52
# File 'lib/tremendous/models/fraud_review.rb', line 50

def related_rewards
  @related_rewards
end

#reviewed_atObject

When the reward was blocked or released following fraud review. This field is only present if the status is not ‘flagged`.



42
43
44
# File 'lib/tremendous/models/fraud_review.rb', line 42

def reviewed_at
  @reviewed_at
end

#reviewed_byObject

The name of the person who reviewed the reward, or ‘Automatic Review` if the reward was blocked automatically. Rewards can be automatically blocked if they remain in the flagged fraud queue for more than 30 days. This field is only present if the status is not `flagged`.



39
40
41
# File 'lib/tremendous/models/fraud_review.rb', line 39

def reviewed_by
  @reviewed_by
end

#rewardObject

Returns the value of attribute reward.



36
37
38
# File 'lib/tremendous/models/fraud_review.rb', line 36

def reward
  @reward
end

#riskObject

The fraud risk associated with the reward.



48
49
50
# File 'lib/tremendous/models/fraud_review.rb', line 48

def risk
  @risk
end

#statusObject

The current status of the fraud review: * ‘flagged` - The reward has been flagged for and waiting manual review. * `blocked` - The reward was reviewed and blocked. * `released` - The reward was reviewed and released.



20
21
22
# File 'lib/tremendous/models/fraud_review.rb', line 20

def status
  @status
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/tremendous/models/fraud_review.rb', line 302

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Tremendous.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



93
94
95
# File 'lib/tremendous/models/fraud_review.rb', line 93

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



98
99
100
# File 'lib/tremendous/models/fraud_review.rb', line 98

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/tremendous/models/fraud_review.rb', line 75

def self.attribute_map
  {
    :'status' => :'status',
    :'reasons' => :'reasons',
    :'device_id' => :'device_id',
    :'redemption_method' => :'redemption_method',
    :'redeemed_at' => :'redeemed_at',
    :'geo' => :'geo',
    :'reward' => :'reward',
    :'reviewed_by' => :'reviewed_by',
    :'reviewed_at' => :'reviewed_at',
    :'redemption_method_account_hash' => :'redemption_method_account_hash',
    :'risk' => :'risk',
    :'related_rewards' => :'related_rewards'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
# File 'lib/tremendous/models/fraud_review.rb', line 278

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



121
122
123
124
# File 'lib/tremendous/models/fraud_review.rb', line 121

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/tremendous/models/fraud_review.rb', line 103

def self.openapi_types
  {
    :'status' => :'String',
    :'reasons' => :'Array<String>',
    :'device_id' => :'String',
    :'redemption_method' => :'String',
    :'redeemed_at' => :'Time',
    :'geo' => :'ListFraudReviews200ResponseFraudReviewsInnerGeo',
    :'reward' => :'OrderWithoutLinkRewardsInner',
    :'reviewed_by' => :'String',
    :'reviewed_at' => :'Time',
    :'redemption_method_account_hash' => :'String',
    :'risk' => :'String',
    :'related_rewards' => :'GetFraudReview200ResponseFraudReviewRelatedRewards'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/tremendous/models/fraud_review.rb', line 246

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      status == o.status &&
      reasons == o.reasons &&
      device_id == o.device_id &&
      redemption_method == o.redemption_method &&
      redeemed_at == o.redeemed_at &&
      geo == o.geo &&
      reward == o.reward &&
      reviewed_by == o.reviewed_by &&
      reviewed_at == o.reviewed_at &&
       == o. &&
      risk == o.risk &&
      related_rewards == o.related_rewards
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



373
374
375
376
377
378
379
380
381
382
383
384
385
# File 'lib/tremendous/models/fraud_review.rb', line 373

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


265
266
267
# File 'lib/tremendous/models/fraud_review.rb', line 265

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



271
272
273
# File 'lib/tremendous/models/fraud_review.rb', line 271

def hash
  [status, reasons, device_id, redemption_method, redeemed_at, geo, reward, reviewed_by, reviewed_at, , risk, related_rewards].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



195
196
197
198
199
# File 'lib/tremendous/models/fraud_review.rb', line 195

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



349
350
351
# File 'lib/tremendous/models/fraud_review.rb', line 349

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'lib/tremendous/models/fraud_review.rb', line 355

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



343
344
345
# File 'lib/tremendous/models/fraud_review.rb', line 343

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



203
204
205
206
207
208
209
210
211
212
# File 'lib/tremendous/models/fraud_review.rb', line 203

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["flagged", "blocked", "released"])
  return false unless status_validator.valid?(@status)
  redemption_method_validator = EnumAttributeValidator.new('String', ["bank transfer", "charity", "instant debit transfer", "international bank transfer", "merchant card", "paypal", "venmo", "visa card"])
  return false unless redemption_method_validator.valid?(@redemption_method)
  risk_validator = EnumAttributeValidator.new('String', ["high", "medium", "low"])
  return false unless risk_validator.valid?(@risk)
  true
end