Class: Tremendous::ListCampaigns200ResponseCampaignsInner
- Inherits:
-
Object
- Object
- Tremendous::ListCampaigns200ResponseCampaignsInner
- Defined in:
- lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb
Overview
With a campaign you can define the look & feel of how rewards are sent out. It also lets you set the available products (different gift cards, charity, etc.) recipients can choose from.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#auto_add_product_rule ⇒ Object
Returns the value of attribute auto_add_product_rule.
-
#description ⇒ Object
Description of the campaign.
-
#email_style ⇒ Object
Returns the value of attribute email_style.
-
#fee_charged_to ⇒ Object
Determines whether fees for premium products are added to the order total (
SENDER) or deducted from the recipient's reward amount (RECIPIENT). -
#id ⇒ Object
Returns the value of attribute id.
-
#name ⇒ Object
Name of the campaign.
-
#products ⇒ Object
List of IDs of products (different gift cards, charity, etc.) that are available in this campaign.
-
#webpage_style ⇒ Object
Returns the value of attribute webpage_style.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListCampaigns200ResponseCampaignsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ListCampaigns200ResponseCampaignsInner
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 110 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Tremendous::ListCampaigns200ResponseCampaignsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Tremendous::ListCampaigns200ResponseCampaignsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = nil end if attributes.key?(:'products') if (value = attributes[:'products']).is_a?(Array) self.products = value end else self.products = nil end if attributes.key?(:'fee_charged_to') self.fee_charged_to = attributes[:'fee_charged_to'] end if attributes.key?(:'auto_add_product_rule') self.auto_add_product_rule = attributes[:'auto_add_product_rule'] end if attributes.key?(:'webpage_style') self.webpage_style = attributes[:'webpage_style'] end if attributes.key?(:'email_style') self.email_style = attributes[:'email_style'] end end |
Instance Attribute Details
#auto_add_product_rule ⇒ Object
Returns the value of attribute auto_add_product_rule.
33 34 35 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 33 def auto_add_product_rule @auto_add_product_rule end |
#description ⇒ Object
Description of the campaign
25 26 27 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 25 def description @description end |
#email_style ⇒ Object
Returns the value of attribute email_style.
37 38 39 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 37 def email_style @email_style end |
#fee_charged_to ⇒ Object
Determines whether fees for premium products are added to the order total (SENDER) or deducted from the recipient's reward amount (RECIPIENT). Campaigns with RECIPIENT must include at least one fee-free product.
31 32 33 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 31 def fee_charged_to @fee_charged_to end |
#id ⇒ Object
Returns the value of attribute id.
19 20 21 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 19 def id @id end |
#name ⇒ Object
Name of the campaign
22 23 24 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 22 def name @name end |
#products ⇒ Object
List of IDs of products (different gift cards, charity, etc.) that are available in this campaign.
28 29 30 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 28 def products @products end |
#webpage_style ⇒ Object
Returns the value of attribute webpage_style.
35 36 37 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 35 def webpage_style @webpage_style end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 295 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Tremendous.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
76 77 78 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 76 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
81 82 83 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 81 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 62 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'description' => :'description', :'products' => :'products', :'fee_charged_to' => :'fee_charged_to', :'auto_add_product_rule' => :'auto_add_product_rule', :'webpage_style' => :'webpage_style', :'email_style' => :'email_style' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 271 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
100 101 102 103 104 105 106 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 100 def self.openapi_nullable Set.new([ :'description', :'fee_charged_to', :'auto_add_product_rule', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 86 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'description' => :'String', :'products' => :'Array<String>', :'fee_charged_to' => :'String', :'auto_add_product_rule' => :'ListCampaigns200ResponseCampaignsInnerAutoAddProductRule', :'webpage_style' => :'ListCampaigns200ResponseCampaignsInnerWebpageStyle', :'email_style' => :'ListCampaigns200ResponseCampaignsInnerEmailStyle' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 243 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && description == o.description && products == o.products && fee_charged_to == o.fee_charged_to && auto_add_product_rule == o.auto_add_product_rule && webpage_style == o.webpage_style && email_style == o.email_style end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
366 367 368 369 370 371 372 373 374 375 376 377 378 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 366 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
258 259 260 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 258 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
264 265 266 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 264 def hash [id, name, description, products, fee_charged_to, auto_add_product_rule, webpage_style, email_style].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 167 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/[A-Z0-9]{4,20}/) if !@id.nil? && @id !~ pattern invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.") end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @products.nil? invalid_properties.push('invalid value for "products", products cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
342 343 344 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 342 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 348 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
336 337 338 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 336 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
188 189 190 191 192 193 194 195 196 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 188 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@id.nil? && @id !~ Regexp.new(/[A-Z0-9]{4,20}/) return false if @name.nil? return false if @products.nil? fee_charged_to_validator = EnumAttributeValidator.new('String', ["SENDER", "RECIPIENT"]) return false unless fee_charged_to_validator.valid?(@fee_charged_to) true end |