Class: Tremendous::ListInvoices200ResponseInvoicesInner
- Inherits:
-
Object
- Object
- Tremendous::ListInvoices200ResponseInvoicesInner
- Defined in:
- lib/tremendous/models/list_invoices200_response_invoices_inner.rb
Overview
Invoices are instruments to fund your Tremendous account’s balance. Invoices can be created by your organization programatically. Once we receive your payment, the invoice is marked as ‘PAID` and we add the respective funds to your account’s balance.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount of the invoice.
-
#created_at ⇒ Object
Timestamp of when the invoice has been created.
-
#currency ⇒ Object
Deprecated: Use ‘currency_code` instead.
-
#currency_code ⇒ Object
Currency of the invoice.
-
#id ⇒ Object
The invoice number.
-
#international ⇒ Object
Returns the value of attribute international.
-
#orders ⇒ Object
List of orders related to the invoice (it doesn’t apply to prefunding).
-
#paid_at ⇒ Object
Timestamp of when the invoice has been paid.
-
#po_number ⇒ Object
Reference to the purchase order number within your organization.
-
#rewards ⇒ Object
List of rewards related to the invoice (it doesn’t apply to prefunding).
-
#status ⇒ Object
Status of this invoice <table> <thead> <tr> <th>Status</th> <th>Description</th> </tr> </thead> <tbody> <tr> <td>
DELETED</td> <td>Invoice has been deleted by your organization</td> </tr> <tr> <td>PAID</td> <td>Invoice has been paid by your organization</td> </tr> <tr> <td>OPEN</td> <td>Invoice has been created by your organization but has not been paid, yet</td> </tr> </tbody> </table>.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListInvoices200ResponseInvoicesInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ListInvoices200ResponseInvoicesInner
Initializes the object
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 127 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Tremendous::ListInvoices200ResponseInvoicesInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Tremendous::ListInvoices200ResponseInvoicesInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'po_number') self.po_number = attributes[:'po_number'] end if attributes.key?(:'amount') self.amount = attributes[:'amount'] else self.amount = nil end if attributes.key?(:'currency_code') self.currency_code = attributes[:'currency_code'] end if attributes.key?(:'currency') self.currency = attributes[:'currency'] end if attributes.key?(:'international') self.international = attributes[:'international'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'orders') if (value = attributes[:'orders']).is_a?(Array) self.orders = value end end if attributes.key?(:'rewards') if (value = attributes[:'rewards']).is_a?(Array) self.rewards = value end end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'paid_at') self.paid_at = attributes[:'paid_at'] else self.paid_at = nil end end |
Instance Attribute Details
#amount ⇒ Object
Amount of the invoice
26 27 28 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 26 def amount @amount end |
#created_at ⇒ Object
Timestamp of when the invoice has been created.
46 47 48 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 46 def created_at @created_at end |
#currency ⇒ Object
Deprecated: Use ‘currency_code` instead.
32 33 34 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 32 def currency @currency end |
#currency_code ⇒ Object
Currency of the invoice
29 30 31 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 29 def currency_code @currency_code end |
#id ⇒ Object
The invoice number
20 21 22 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 20 def id @id end |
#international ⇒ Object
Returns the value of attribute international.
34 35 36 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 34 def international @international end |
#orders ⇒ Object
List of orders related to the invoice (it doesn’t apply to prefunding)
40 41 42 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 40 def orders @orders end |
#paid_at ⇒ Object
Timestamp of when the invoice has been paid.
49 50 51 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 49 def paid_at @paid_at end |
#po_number ⇒ Object
Reference to the purchase order number within your organization
23 24 25 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 23 def po_number @po_number end |
#rewards ⇒ Object
List of rewards related to the invoice (it doesn’t apply to prefunding)
43 44 45 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 43 def rewards @rewards end |
#status ⇒ Object
Status of this invoice <table> <thead> <tr> <th>Status</th> <th>Description</th> </tr> </thead> <tbody> <tr> <td>DELETED</td> <td>Invoice has been deleted by your organization</td> </tr> <tr> <td>PAID</td> <td>Invoice has been paid by your organization</td> </tr> <tr> <td>OPEN</td> <td>Invoice has been created by your organization but has not been paid, yet</td> </tr> </tbody> </table>
37 38 39 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 37 def status @status end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 358 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Tremendous.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
91 92 93 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 91 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
96 97 98 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 96 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 74 def self.attribute_map { :'id' => :'id', :'po_number' => :'po_number', :'amount' => :'amount', :'currency_code' => :'currency_code', :'currency' => :'currency', :'international' => :'international', :'status' => :'status', :'orders' => :'orders', :'rewards' => :'rewards', :'created_at' => :'created_at', :'paid_at' => :'paid_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 334 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
118 119 120 121 122 123 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 118 def self.openapi_nullable Set.new([ :'po_number', :'paid_at' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 101 def self.openapi_types { :'id' => :'String', :'po_number' => :'String', :'amount' => :'Float', :'currency_code' => :'String', :'currency' => :'String', :'international' => :'Boolean', :'status' => :'String', :'orders' => :'Array<String>', :'rewards' => :'Array<String>', :'created_at' => :'Time', :'paid_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 303 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && po_number == o.po_number && amount == o.amount && currency_code == o.currency_code && currency == o.currency && international == o.international && status == o.status && orders == o.orders && rewards == o.rewards && created_at == o.created_at && paid_at == o.paid_at end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
429 430 431 432 433 434 435 436 437 438 439 440 441 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 429 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
321 322 323 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 321 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
327 328 329 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 327 def hash [id, po_number, amount, currency_code, currency, international, status, orders, rewards, created_at, paid_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 202 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @amount.nil? invalid_properties.push('invalid value for "amount", amount cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
405 406 407 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 405 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
411 412 413 414 415 416 417 418 419 420 421 422 423 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 411 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
399 400 401 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 399 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/tremendous/models/list_invoices200_response_invoices_inner.rb', line 226 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @amount.nil? currency_code_validator = EnumAttributeValidator.new('String', ["USD", "EUR", "GBP"]) return false unless currency_code_validator.valid?(@currency_code) currency_validator = EnumAttributeValidator.new('String', ["USD", "EUR", "GBP"]) return false unless currency_validator.valid?(@currency) return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["DELETED", "PAID", "OPEN", "MARKED_AS_PAID"]) return false unless status_validator.valid?(@status) return false if @created_at.nil? true end |