Class: Tremendous::ListProductsResponseProductsInner

Inherits:
Object
  • Object
show all
Defined in:
lib/tremendous/models/list_products_response_products_inner.rb

Overview

A product represents one way to payout a reward to its recipient. Think: * Amazon.com gift card (ID: ‘OKMHM2X2OHYV`) * Donations to Save the Children (ID: `ESRNAD533W5A`) * Virtual Visa debit card (ID: `Q24BD9EZ332JT`) each of which is one specific product on Tremendous. > 📘 All available products > > See this [list](www.tremendous.com/catalog) Products can be limited in their availability to recipients by * geography (field `countries`) * currency (field `currencies`) * amount of the reward (field `skus`) * e.g. adidas gift cards accept any amount between 5 and 200 USD. See the description of each respective parameter for further details.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ListProductsResponseProductsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 130

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Tremendous::ListProductsResponseProductsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Tremendous::ListProductsResponseProductsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  else
    self.category = nil
  end

  if attributes.key?(:'subcategory')
    self.subcategory = attributes[:'subcategory']
  end

  if attributes.key?(:'disclosure')
    self.disclosure = attributes[:'disclosure']
  else
    self.disclosure = nil
  end

  if attributes.key?(:'skus')
    if (value = attributes[:'skus']).is_a?(Array)
      self.skus = value
    end
  end

  if attributes.key?(:'currency_codes')
    if (value = attributes[:'currency_codes']).is_a?(Array)
      self.currency_codes = value
    end
  else
    self.currency_codes = nil
  end

  if attributes.key?(:'countries')
    if (value = attributes[:'countries']).is_a?(Array)
      self.countries = value
    end
  else
    self.countries = nil
  end

  if attributes.key?(:'images')
    if (value = attributes[:'images']).is_a?(Array)
      self.images = value
    end
  else
    self.images = nil
  end

  if attributes.key?(:'usage_instructions')
    self.usage_instructions = attributes[:'usage_instructions']
  end

  if attributes.key?(:'documents')
    self.documents = attributes[:'documents']
  end
end

Instance Attribute Details

#categoryObject

The category of the product <table> <thead> <tr> <th>Category</th> <th>Description</th> </tr> </thead> <tbody> <tr> <td>ach</td> <td>Bank transfer to the recipient</td> </tr> <tr> <td>charity</td> <td>Donations to a charity</td> </tr> <tr> <td>instant_debit_transfer</td> <td>Instant debit transfer to the recipient</td> </tr> <tr> <td>merchant_card</td> <td>A gift card for a certain merchant (e.g. Amazon)</td> </tr> <tr> <td>paypal</td> <td>Payout via PayPal</td> </tr> <tr> <td>venmo</td> <td>Payout via Venmo</td> </tr> <tr> <td>visa_card</td> <td>Payout in form of a Visa debit card</td> </tr> <tr> <td>cash_app</td> <td>Payout via Cash App</td> </tr> <tr> <td>international_bank</td> <td>Bank transfer to recipients outside of the US</td> </tr> </tbody> </table>



28
29
30
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 28

def category
  @category
end

#countriesObject

List of countries in which this product is available to recipients.



43
44
45
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 43

def countries
  @countries
end

#currency_codesObject

Available currencies for this product



40
41
42
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 40

def currency_codes
  @currency_codes
end

#descriptionObject

Detailed description of the product.



25
26
27
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 25

def description
  @description
end

#disclosureObject

Legal disclosures for this product. Can be in HTML format.



34
35
36
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 34

def disclosure
  @disclosure
end

#documentsObject

Returns the value of attribute documents.



51
52
53
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 51

def documents
  @documents
end

#idObject

Returns the value of attribute id.



19
20
21
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 19

def id
  @id
end

#imagesObject

List of product images associated with this product (e.g. logos or images of the gift cards)



46
47
48
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 46

def images
  @images
end

#nameObject

Name of the product



22
23
24
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 22

def name
  @name
end

#skusObject

Products are restricted in their usage based on the amount of the reward. The ‘skus` array defines bands of denominations in which this product may be used for payouts.



37
38
39
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 37

def skus
  @skus
end

#subcategoryObject

Additional classification for the product. Only applicable to products with a ‘category` of `merchant_card`. Possible subcategories: * `beauty_and_health` * `digital_financial_services` * `electronics` * `entertainment` * `fashion` * `food_and_drink` * `general_merchandise` * `grocery_and_supermarkets` * `home_and_living` * `mobility_and_fuel` * `sports_and_outdoor_gear` * `travel_and_hospitality`



31
32
33
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 31

def subcategory
  @subcategory
end

#usage_instructionsObject

Instructions for how to use the product, if applicable. Mostly used for products with a ‘category` of `merchant_card`.



49
50
51
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 49

def usage_instructions
  @usage_instructions
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 448

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Tremendous.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



94
95
96
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 94

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



99
100
101
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 99

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 76

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'description' => :'description',
    :'category' => :'category',
    :'subcategory' => :'subcategory',
    :'disclosure' => :'disclosure',
    :'skus' => :'skus',
    :'currency_codes' => :'currency_codes',
    :'countries' => :'countries',
    :'images' => :'images',
    :'usage_instructions' => :'usage_instructions',
    :'documents' => :'documents'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 424

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



122
123
124
125
126
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 122

def self.openapi_nullable
  Set.new([
    :'documents'
  ])
end

.openapi_typesObject

Attribute type mapping.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 104

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'category' => :'String',
    :'subcategory' => :'String',
    :'disclosure' => :'String',
    :'skus' => :'Array<ListProductsResponseProductsInnerSkusInner>',
    :'currency_codes' => :'Array<String>',
    :'countries' => :'Array<ListProductsResponseProductsInnerCountriesInner>',
    :'images' => :'Array<ListProductsResponseProductsInnerImagesInner>',
    :'usage_instructions' => :'String',
    :'documents' => :'ListProductsResponseProductsInnerDocuments'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 392

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      description == o.description &&
      category == o.category &&
      subcategory == o.subcategory &&
      disclosure == o.disclosure &&
      skus == o.skus &&
      currency_codes == o.currency_codes &&
      countries == o.countries &&
      images == o.images &&
      usage_instructions == o.usage_instructions &&
      documents == o.documents
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



519
520
521
522
523
524
525
526
527
528
529
530
531
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 519

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


411
412
413
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 411

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



417
418
419
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 417

def hash
  [id, name, description, category, subcategory, disclosure, skus, currency_codes, countries, images, usage_instructions, documents].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 219

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  pattern = Regexp.new(/[A-Z0-9]{4,20}/)
  if @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @category.nil?
    invalid_properties.push('invalid value for "category", category cannot be nil.')
  end

  if @disclosure.nil?
    invalid_properties.push('invalid value for "disclosure", disclosure cannot be nil.')
  end

  if @currency_codes.nil?
    invalid_properties.push('invalid value for "currency_codes", currency_codes cannot be nil.')
  end

  if @currency_codes.length < 1
    invalid_properties.push('invalid value for "currency_codes", number of items must be greater than or equal to 1.')
  end

  if @countries.nil?
    invalid_properties.push('invalid value for "countries", countries cannot be nil.')
  end

  if @countries.length < 1
    invalid_properties.push('invalid value for "countries", number of items must be greater than or equal to 1.')
  end

  if @images.nil?
    invalid_properties.push('invalid value for "images", images cannot be nil.')
  end

  if @images.length < 0
    invalid_properties.push('invalid value for "images", number of items must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



495
496
497
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 495

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



501
502
503
504
505
506
507
508
509
510
511
512
513
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 501

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



489
490
491
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 489

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/tremendous/models/list_products_response_products_inner.rb', line 276

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @id !~ Regexp.new(/[A-Z0-9]{4,20}/)
  return false if @name.nil?
  return false if @description.nil?
  return false if @category.nil?
  category_validator = EnumAttributeValidator.new('String', ["ach", "charity", "instant_debit_transfer", "merchant_card", "paypal", "venmo", "visa_card", "cash_app", "international_bank"])
  return false unless category_validator.valid?(@category)
  subcategory_validator = EnumAttributeValidator.new('String', ["beauty_and_health", "digital_financial_services", "electronics", "entertainment", "fashion", "food_and_drink", "general_merchandise", "grocery_and_supermarkets", "home_and_living", "mobility_and_fuel", "sports_and_outdoor_gear", "travel_and_hospitality"])
  return false unless subcategory_validator.valid?(@subcategory)
  return false if @disclosure.nil?
  return false if @currency_codes.nil?
  return false if @currency_codes.length < 1
  return false if @countries.nil?
  return false if @countries.length < 1
  return false if @images.nil?
  return false if @images.length < 0
  true
end