Class: Tremendous::Member
- Inherits:
-
Object
- Object
- Tremendous::Member
- Defined in:
- lib/tremendous/models/member.rb
Overview
Each organization has one or more users that can access and manage that organization. These users are called members. Members can take actions via the Tremendous web dashboard directly. These actions include adding funding sources to the organization, creating Campaigns, and more.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#active ⇒ Object
Is this member currently active in the organization.
-
#created_at ⇒ Object
Timestamp when this member was created.
-
#email ⇒ Object
Email address of the member.
-
#id ⇒ Object
Returns the value of attribute id.
-
#last_login_at ⇒ Object
Timestamp when this member most recently logged into the dashboard of the organization associated with this API key.
-
#name ⇒ Object
Full name of the member.
-
#role ⇒ Object
The role ID associated with the member within the organization.
-
#status ⇒ Object
Current status of the member’s account.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Member
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Member
Initializes the object
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/tremendous/models/member.rb', line 113 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Tremendous::Member` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Tremendous::Member`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'email') self.email = attributes[:'email'] else self.email = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'active') self.active = attributes[:'active'] end if attributes.key?(:'role') self.role = attributes[:'role'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'last_login_at') self.last_login_at = attributes[:'last_login_at'] end end |
Instance Attribute Details
#active ⇒ Object
Is this member currently active in the organization. If ‘false`, the member will not be able to access the organization.
28 29 30 |
# File 'lib/tremendous/models/member.rb', line 28 def active @active end |
#created_at ⇒ Object
Timestamp when this member was created. The ‘created_at` timestamp is NOT returned when retrieving a member (but is part of the response when listing or creating members).
37 38 39 |
# File 'lib/tremendous/models/member.rb', line 37 def created_at @created_at end |
#email ⇒ Object
Email address of the member
22 23 24 |
# File 'lib/tremendous/models/member.rb', line 22 def email @email end |
#id ⇒ Object
Returns the value of attribute id.
19 20 21 |
# File 'lib/tremendous/models/member.rb', line 19 def id @id end |
#last_login_at ⇒ Object
Timestamp when this member most recently logged into the dashboard of the organization associated with this API key.
40 41 42 |
# File 'lib/tremendous/models/member.rb', line 40 def last_login_at @last_login_at end |
#name ⇒ Object
Full name of the member
25 26 27 |
# File 'lib/tremendous/models/member.rb', line 25 def name @name end |
#role ⇒ Object
The role ID associated with the member within the organization.
31 32 33 |
# File 'lib/tremendous/models/member.rb', line 31 def role @role end |
#status ⇒ Object
Current status of the member’s account. When creating a member it starts out in the status ‘INVITED`. As soon as that member open the invitation link and registers an account, the status switches to `REGISTERED`.
34 35 36 |
# File 'lib/tremendous/models/member.rb', line 34 def status @status end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/tremendous/models/member.rb', line 295 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Tremendous.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
79 80 81 |
# File 'lib/tremendous/models/member.rb', line 79 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
84 85 86 |
# File 'lib/tremendous/models/member.rb', line 84 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/tremendous/models/member.rb', line 65 def self.attribute_map { :'id' => :'id', :'email' => :'email', :'name' => :'name', :'active' => :'active', :'role' => :'role', :'status' => :'status', :'created_at' => :'created_at', :'last_login_at' => :'last_login_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/tremendous/models/member.rb', line 271 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
103 104 105 106 107 108 109 |
# File 'lib/tremendous/models/member.rb', line 103 def self.openapi_nullable Set.new([ :'name', :'role', :'last_login_at' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/tremendous/models/member.rb', line 89 def self.openapi_types { :'id' => :'String', :'email' => :'String', :'name' => :'String', :'active' => :'Boolean', :'role' => :'String', :'status' => :'String', :'created_at' => :'Time', :'last_login_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/tremendous/models/member.rb', line 243 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && email == o.email && name == o.name && active == o.active && role == o.role && status == o.status && created_at == o.created_at && last_login_at == o.last_login_at end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
366 367 368 369 370 371 372 373 374 375 376 377 378 |
# File 'lib/tremendous/models/member.rb', line 366 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
258 259 260 |
# File 'lib/tremendous/models/member.rb', line 258 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
264 265 266 |
# File 'lib/tremendous/models/member.rb', line 264 def hash [id, email, name, active, role, status, created_at, last_login_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/tremendous/models/member.rb', line 170 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end pattern = Regexp.new(/[A-Z0-9]{4,20}/) if @id !~ pattern invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.") end if @email.nil? invalid_properties.push('invalid value for "email", email cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
342 343 344 |
# File 'lib/tremendous/models/member.rb', line 342 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/tremendous/models/member.rb', line 348 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
336 337 338 |
# File 'lib/tremendous/models/member.rb', line 336 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
195 196 197 198 199 200 201 202 203 204 |
# File 'lib/tremendous/models/member.rb', line 195 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @id !~ Regexp.new(/[A-Z0-9]{4,20}/) return false if @email.nil? return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["REGISTERED", "INVITED"]) return false unless status_validator.valid?(@status) true end |