Class: Tremendous::PaymentDetails
- Inherits:
-
Object
- Object
- Tremendous::PaymentDetails
- Defined in:
- lib/tremendous/models/payment_details.rb
Instance Attribute Summary collapse
-
#discount ⇒ Object
Discount for the order (in USD).
-
#fees ⇒ Object
Fees for the order (in USD).
-
#refund ⇒ Object
Returns the value of attribute refund.
-
#subtotal ⇒ Object
Total price of the order before fees (in USD).
-
#total ⇒ Object
Total price of the order including fees (in USD).
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PaymentDetails
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PaymentDetails
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/tremendous/models/payment_details.rb', line 72 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Tremendous::PaymentDetails` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Tremendous::PaymentDetails`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'subtotal') self.subtotal = attributes[:'subtotal'] else self.subtotal = nil end if attributes.key?(:'total') self.total = attributes[:'total'] else self.total = nil end if attributes.key?(:'fees') self.fees = attributes[:'fees'] else self.fees = nil end if attributes.key?(:'discount') self.discount = attributes[:'discount'] else self.discount = nil end if attributes.key?(:'refund') self.refund = attributes[:'refund'] end end |
Instance Attribute Details
#discount ⇒ Object
Discount for the order (in USD)
28 29 30 |
# File 'lib/tremendous/models/payment_details.rb', line 28 def discount @discount end |
#fees ⇒ Object
Fees for the order (in USD)
25 26 27 |
# File 'lib/tremendous/models/payment_details.rb', line 25 def fees @fees end |
#refund ⇒ Object
Returns the value of attribute refund.
30 31 32 |
# File 'lib/tremendous/models/payment_details.rb', line 30 def refund @refund end |
#subtotal ⇒ Object
Total price of the order before fees (in USD)
19 20 21 |
# File 'lib/tremendous/models/payment_details.rb', line 19 def subtotal @subtotal end |
#total ⇒ Object
Total price of the order including fees (in USD)
22 23 24 |
# File 'lib/tremendous/models/payment_details.rb', line 22 def total @total end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/tremendous/models/payment_details.rb', line 277 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Tremendous.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
44 45 46 |
# File 'lib/tremendous/models/payment_details.rb', line 44 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
49 50 51 |
# File 'lib/tremendous/models/payment_details.rb', line 49 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 |
# File 'lib/tremendous/models/payment_details.rb', line 33 def self.attribute_map { :'subtotal' => :'subtotal', :'total' => :'total', :'fees' => :'fees', :'discount' => :'discount', :'refund' => :'refund' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/tremendous/models/payment_details.rb', line 253 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
65 66 67 68 |
# File 'lib/tremendous/models/payment_details.rb', line 65 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 |
# File 'lib/tremendous/models/payment_details.rb', line 54 def self.openapi_types { :'subtotal' => :'Float', :'total' => :'Float', :'fees' => :'Float', :'discount' => :'Float', :'refund' => :'PaymentDetailsRefund' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
228 229 230 231 232 233 234 235 236 |
# File 'lib/tremendous/models/payment_details.rb', line 228 def ==(o) return true if self.equal?(o) self.class == o.class && subtotal == o.subtotal && total == o.total && fees == o.fees && discount == o.discount && refund == o.refund end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/tremendous/models/payment_details.rb', line 348 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
240 241 242 |
# File 'lib/tremendous/models/payment_details.rb', line 240 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
246 247 248 |
# File 'lib/tremendous/models/payment_details.rb', line 246 def hash [subtotal, total, fees, discount, refund].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/tremendous/models/payment_details.rb', line 117 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @subtotal.nil? invalid_properties.push('invalid value for "subtotal", subtotal cannot be nil.') end if @subtotal < 0 invalid_properties.push('invalid value for "subtotal", must be greater than or equal to 0.') end if @total.nil? invalid_properties.push('invalid value for "total", total cannot be nil.') end if @total < 0 invalid_properties.push('invalid value for "total", must be greater than or equal to 0.') end if @fees.nil? invalid_properties.push('invalid value for "fees", fees cannot be nil.') end if @fees < 0 invalid_properties.push('invalid value for "fees", must be greater than or equal to 0.') end if @discount.nil? invalid_properties.push('invalid value for "discount", discount cannot be nil.') end if @discount < 0 invalid_properties.push('invalid value for "discount", must be greater than or equal to 0.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
324 325 326 |
# File 'lib/tremendous/models/payment_details.rb', line 324 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/tremendous/models/payment_details.rb', line 330 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
318 319 320 |
# File 'lib/tremendous/models/payment_details.rb', line 318 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/tremendous/models/payment_details.rb', line 157 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @subtotal.nil? return false if @subtotal < 0 return false if @total.nil? return false if @total < 0 return false if @fees.nil? return false if @fees < 0 return false if @discount.nil? return false if @discount < 0 true end |