Class: Tremendous::RewardForOrderCreate
- Inherits:
-
Object
- Object
- Tremendous::RewardForOrderCreate
- Defined in:
- lib/tremendous/models/reward_for_order_create.rb
Overview
A single reward, sent to a recipient. A reward is always part of an order. Either ‘products` or `campaign_id` must be specified.
Instance Attribute Summary collapse
-
#campaign_id ⇒ Object
ID of the campaign in your account, that defines the available products (different gift cards, charity, etc.) that the recipient can choose from.
-
#created_at ⇒ Object
Date the reward was created.
-
#custom_fields ⇒ Object
Returns the value of attribute custom_fields.
-
#deliver_at ⇒ Object
Timestamp of reward delivery within the next year.
-
#delivery ⇒ Object
Returns the value of attribute delivery.
-
#expires_at ⇒ Object
Expiration date of the reward.
-
#id ⇒ Object
Tremendous ID of the reward.
-
#language ⇒ Object
Set this to translate the redemption experience for this reward.
-
#order_id ⇒ Object
Tremendous ID of the order this reward is part of.
-
#products ⇒ Object
List of IDs of product (different gift cards, charity, etc.) that will be available to the recipient to choose from.
-
#recipient ⇒ Object
Returns the value of attribute recipient.
-
#value ⇒ Object
Returns the value of attribute value.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RewardForOrderCreate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ RewardForOrderCreate
Initializes the object
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 107 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Tremendous::RewardForOrderCreate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Tremendous::RewardForOrderCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'order_id') self.order_id = attributes[:'order_id'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] end if attributes.key?(:'campaign_id') self.campaign_id = attributes[:'campaign_id'] end if attributes.key?(:'products') if (value = attributes[:'products']).is_a?(Array) self.products = value end end if attributes.key?(:'value') self.value = attributes[:'value'] end if attributes.key?(:'recipient') self.recipient = attributes[:'recipient'] end if attributes.key?(:'deliver_at') self.deliver_at = attributes[:'deliver_at'] end if attributes.key?(:'custom_fields') if (value = attributes[:'custom_fields']).is_a?(Array) self.custom_fields = value end end if attributes.key?(:'language') self.language = attributes[:'language'] end if attributes.key?(:'delivery') self.delivery = attributes[:'delivery'] end end |
Instance Attribute Details
#campaign_id ⇒ Object
ID of the campaign in your account, that defines the available products (different gift cards, charity, etc.) that the recipient can choose from.
32 33 34 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 32 def campaign_id @campaign_id end |
#created_at ⇒ Object
Date the reward was created
26 27 28 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 26 def created_at @created_at end |
#custom_fields ⇒ Object
Returns the value of attribute custom_fields.
44 45 46 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 44 def custom_fields @custom_fields end |
#deliver_at ⇒ Object
Timestamp of reward delivery within the next year. Note that if date-time is provided, the time values will be ignored.
42 43 44 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 42 def deliver_at @deliver_at end |
#delivery ⇒ Object
Returns the value of attribute delivery.
49 50 51 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 49 def delivery @delivery end |
#expires_at ⇒ Object
Expiration date of the reward. If null, the reward does not expire.
29 30 31 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 29 def expires_at @expires_at end |
#id ⇒ Object
Tremendous ID of the reward
20 21 22 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 20 def id @id end |
#language ⇒ Object
Set this to translate the redemption experience for this reward. Pass a 2-letter [ISO-639-1 code](en.wikipedia.org/wiki/List_of_ISO_639-1_codes) for the desired language. Defaults to ‘en`.
47 48 49 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 47 def language @language end |
#order_id ⇒ Object
Tremendous ID of the order this reward is part of.
23 24 25 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 23 def order_id @order_id end |
#products ⇒ Object
List of IDs of product (different gift cards, charity, etc.) that will be available to the recipient to choose from. Providing a ‘products` array will override the products made available by the campaign specified using the `campaign_id` property unless the `products` array is empty. It will not override other campaign attributes, like the message and customization of the look and feel.
35 36 37 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 35 def products @products end |
#recipient ⇒ Object
Returns the value of attribute recipient.
39 40 41 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 39 def recipient @recipient end |
#value ⇒ Object
Returns the value of attribute value.
37 38 39 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 37 def value @value end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 325 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Tremendous.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
70 71 72 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 70 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
75 76 77 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 75 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 52 def self.attribute_map { :'id' => :'id', :'order_id' => :'order_id', :'created_at' => :'created_at', :'expires_at' => :'expires_at', :'campaign_id' => :'campaign_id', :'products' => :'products', :'value' => :'value', :'recipient' => :'recipient', :'deliver_at' => :'deliver_at', :'custom_fields' => :'custom_fields', :'language' => :'language', :'delivery' => :'delivery' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 301 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 102 103 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 98 def self.openapi_nullable Set.new([ :'expires_at', :'campaign_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 80 def self.openapi_types { :'id' => :'String', :'order_id' => :'String', :'created_at' => :'Time', :'expires_at' => :'Time', :'campaign_id' => :'String', :'products' => :'Array<String>', :'value' => :'ListRewards200ResponseRewardsInnerValue', :'recipient' => :'ListRewards200ResponseRewardsInnerRecipient', :'deliver_at' => :'Date', :'custom_fields' => :'Array<RewardBaseCustomFieldsInner>', :'language' => :'String', :'delivery' => :'SingleRewardOrderRewardDelivery' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 269 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && order_id == o.order_id && created_at == o.created_at && expires_at == o.expires_at && campaign_id == o.campaign_id && products == o.products && value == o.value && recipient == o.recipient && deliver_at == o.deliver_at && custom_fields == o.custom_fields && language == o.language && delivery == o.delivery end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
396 397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 396 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
288 289 290 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 288 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
294 295 296 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 294 def hash [id, order_id, created_at, expires_at, campaign_id, products, value, recipient, deliver_at, custom_fields, language, delivery].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 176 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/[A-Z0-9]{4,20}/) if !@id.nil? && @id !~ pattern invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/[A-Z0-9]{4,20}/) if !@order_id.nil? && @order_id !~ pattern invalid_properties.push("invalid value for \"order_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/[A-Z0-9]{4,20}/) if !@campaign_id.nil? && @campaign_id !~ pattern invalid_properties.push("invalid value for \"campaign_id\", must conform to the pattern #{pattern}.") end if !@products.nil? && @products.length < 1 invalid_properties.push('invalid value for "products", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
372 373 374 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 372 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
378 379 380 381 382 383 384 385 386 387 388 389 390 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 378 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
366 367 368 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 366 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
203 204 205 206 207 208 209 210 |
# File 'lib/tremendous/models/reward_for_order_create.rb', line 203 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@id.nil? && @id !~ Regexp.new(/[A-Z0-9]{4,20}/) return false if !@order_id.nil? && @order_id !~ Regexp.new(/[A-Z0-9]{4,20}/) return false if !@campaign_id.nil? && @campaign_id !~ Regexp.new(/[A-Z0-9]{4,20}/) return false if !@products.nil? && @products.length < 1 true end |