Class: Tremendous::FraudReview
- Inherits:
-
Object
- Object
- Tremendous::FraudReview
- Defined in:
- lib/tremendous/models/fraud_review.rb
Overview
The fraud review associated with a reward.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#device_id ⇒ Object
The device fingerprint, if known.
-
#geo ⇒ Object
Returns the value of attribute geo.
-
#reasons ⇒ Object
The array may contain multiple reasons, depending on which rule(s) flagged the reward for review.
-
#redeemed_at ⇒ Object
Date the reward was redeemed.
-
#redemption_method ⇒ Object
The product selected to claim the reward.
-
#related_rewards ⇒ Object
Returns the value of attribute related_rewards.
-
#reviewed_at ⇒ Object
When the reward was blocked or released following fraud review.
-
#reviewed_by ⇒ Object
The name of the person who reviewed the reward, or ‘Automatic Review` if the reward was blocked automatically.
-
#reward ⇒ Object
Returns the value of attribute reward.
-
#risk ⇒ Object
The fraud risk associated with the reward.
-
#status ⇒ Object
The current status of the fraud review: * ‘flagged` - The reward has been flagged for and waiting manual review.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FraudReview
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ FraudReview
Initializes the object
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/tremendous/models/fraud_review.rb', line 118 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Tremendous::FraudReview` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Tremendous::FraudReview`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'risk') self.risk = attributes[:'risk'] end if attributes.key?(:'reasons') if (value = attributes[:'reasons']).is_a?(Array) self.reasons = value end end if attributes.key?(:'reviewed_by') self.reviewed_by = attributes[:'reviewed_by'] end if attributes.key?(:'reviewed_at') self.reviewed_at = attributes[:'reviewed_at'] end if attributes.key?(:'related_rewards') self. = attributes[:'related_rewards'] end if attributes.key?(:'device_id') self.device_id = attributes[:'device_id'] end if attributes.key?(:'redemption_method') self.redemption_method = attributes[:'redemption_method'] end if attributes.key?(:'redeemed_at') self.redeemed_at = attributes[:'redeemed_at'] end if attributes.key?(:'geo') self.geo = attributes[:'geo'] end if attributes.key?(:'reward') self.reward = attributes[:'reward'] end end |
Instance Attribute Details
#device_id ⇒ Object
The device fingerprint, if known.
37 38 39 |
# File 'lib/tremendous/models/fraud_review.rb', line 37 def device_id @device_id end |
#geo ⇒ Object
Returns the value of attribute geo.
45 46 47 |
# File 'lib/tremendous/models/fraud_review.rb', line 45 def geo @geo end |
#reasons ⇒ Object
The array may contain multiple reasons, depending on which rule(s) flagged the reward for review. Reasons can be any of the following: * ‘Disallowed IP` * `Disallowed email` * `Disallowed country` * `Over reward dollar limit` * `Over reward count limit` * `VPN detected` * `Device related to multiple emails` * `Device or account related to multiple emails` * `IP on a Tremendous fraud list` * `Bank account on a Tremendous fraud list` * `Fingerprint on a Tremendous fraud list` * `Email on a Tremendous fraud list` * `Phone on a Tremendous fraud list` * `IP related to a blocked reward` * `Device related to a blocked reward` * `Bank account related to a blocked reward` * `Fingerprint related to a blocked reward` * `Email related to a blocked reward` * `Phone related to a blocked reward` * `Allowed IP` * `Allowed email`
26 27 28 |
# File 'lib/tremendous/models/fraud_review.rb', line 26 def reasons @reasons end |
#redeemed_at ⇒ Object
Date the reward was redeemed
43 44 45 |
# File 'lib/tremendous/models/fraud_review.rb', line 43 def redeemed_at @redeemed_at end |
#redemption_method ⇒ Object
The product selected to claim the reward
40 41 42 |
# File 'lib/tremendous/models/fraud_review.rb', line 40 def redemption_method @redemption_method end |
#related_rewards ⇒ Object
Returns the value of attribute related_rewards.
34 35 36 |
# File 'lib/tremendous/models/fraud_review.rb', line 34 def @related_rewards end |
#reviewed_at ⇒ Object
When the reward was blocked or released following fraud review. This field is only present if the status is not ‘flagged`.
32 33 34 |
# File 'lib/tremendous/models/fraud_review.rb', line 32 def reviewed_at @reviewed_at end |
#reviewed_by ⇒ Object
The name of the person who reviewed the reward, or ‘Automatic Review` if the reward was blocked automatically. Rewards can be automatically blocked if they remain in the flagged fraud queue for more than 30 days. This field is only present if the status is not `flagged`.
29 30 31 |
# File 'lib/tremendous/models/fraud_review.rb', line 29 def reviewed_by @reviewed_by end |
#reward ⇒ Object
Returns the value of attribute reward.
47 48 49 |
# File 'lib/tremendous/models/fraud_review.rb', line 47 def reward @reward end |
#risk ⇒ Object
The fraud risk associated with the reward.
23 24 25 |
# File 'lib/tremendous/models/fraud_review.rb', line 23 def risk @risk end |
#status ⇒ Object
The current status of the fraud review: * ‘flagged` - The reward has been flagged for and waiting manual review. * `blocked` - The reward was reviewed and blocked. * `released` - The reward was reviewed and released.
20 21 22 |
# File 'lib/tremendous/models/fraud_review.rb', line 20 def status @status end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/tremendous/models/fraud_review.rb', line 286 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Tremendous.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
89 90 91 |
# File 'lib/tremendous/models/fraud_review.rb', line 89 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/tremendous/models/fraud_review.rb', line 72 def self.attribute_map { :'status' => :'status', :'risk' => :'risk', :'reasons' => :'reasons', :'reviewed_by' => :'reviewed_by', :'reviewed_at' => :'reviewed_at', :'related_rewards' => :'related_rewards', :'device_id' => :'device_id', :'redemption_method' => :'redemption_method', :'redeemed_at' => :'redeemed_at', :'geo' => :'geo', :'reward' => :'reward' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/tremendous/models/fraud_review.rb', line 262 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
111 112 113 114 |
# File 'lib/tremendous/models/fraud_review.rb', line 111 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/tremendous/models/fraud_review.rb', line 94 def self.openapi_types { :'status' => :'String', :'risk' => :'String', :'reasons' => :'Array<String>', :'reviewed_by' => :'String', :'reviewed_at' => :'Time', :'related_rewards' => :'GetFraudReview200ResponseFraudReviewRelatedRewards', :'device_id' => :'String', :'redemption_method' => :'String', :'redeemed_at' => :'Time', :'geo' => :'GetFraudReview200ResponseFraudReviewGeo', :'reward' => :'OrderWithoutLinkRewardsInner' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/tremendous/models/fraud_review.rb', line 231 def ==(o) return true if self.equal?(o) self.class == o.class && status == o.status && risk == o.risk && reasons == o.reasons && reviewed_by == o.reviewed_by && reviewed_at == o.reviewed_at && == o. && device_id == o.device_id && redemption_method == o.redemption_method && redeemed_at == o.redeemed_at && geo == o.geo && reward == o.reward end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
357 358 359 360 361 362 363 364 365 366 367 368 369 |
# File 'lib/tremendous/models/fraud_review.rb', line 357 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
249 250 251 |
# File 'lib/tremendous/models/fraud_review.rb', line 249 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
255 256 257 |
# File 'lib/tremendous/models/fraud_review.rb', line 255 def hash [status, risk, reasons, reviewed_by, reviewed_at, , device_id, redemption_method, redeemed_at, geo, reward].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
180 181 182 183 184 |
# File 'lib/tremendous/models/fraud_review.rb', line 180 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
333 334 335 |
# File 'lib/tremendous/models/fraud_review.rb', line 333 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
339 340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/tremendous/models/fraud_review.rb', line 339 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
327 328 329 |
# File 'lib/tremendous/models/fraud_review.rb', line 327 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
188 189 190 191 192 193 194 195 196 197 |
# File 'lib/tremendous/models/fraud_review.rb', line 188 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["flagged", "blocked", "released"]) return false unless status_validator.valid?(@status) risk_validator = EnumAttributeValidator.new('String', ["high", "medium", "low"]) return false unless risk_validator.valid?(@risk) redemption_method_validator = EnumAttributeValidator.new('String', ["paypal", "bank", "merchant card", "visa card", "charity", "venmo"]) return false unless redemption_method_validator.valid?(@redemption_method) true end |