Class: Tremendous::ListCampaigns200ResponseCampaignsInner
- Inherits:
-
Object
- Object
- Tremendous::ListCampaigns200ResponseCampaignsInner
- Defined in:
- lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb
Overview
With a campaign you can define the look & feel of how rewards are sent out. It also lets you set the available products (different gift cards, charity, etc.) recipients can choose from.
Instance Attribute Summary collapse
-
#description ⇒ Object
Description of the campaign.
-
#email_style ⇒ Object
Returns the value of attribute email_style.
-
#id ⇒ Object
Returns the value of attribute id.
-
#name ⇒ Object
Name of the campaign.
-
#products ⇒ Object
List of IDs of products (different gift cards, charity, etc.) that are available in this campaign.
-
#webpage_style ⇒ Object
Returns the value of attribute webpage_style.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListCampaigns200ResponseCampaignsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ListCampaigns200ResponseCampaignsInner
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 72 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Tremendous::ListCampaigns200ResponseCampaignsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Tremendous::ListCampaigns200ResponseCampaignsInner`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = nil end if attributes.key?(:'products') if (value = attributes[:'products']).is_a?(Array) self.products = value end else self.products = nil end if attributes.key?(:'webpage_style') self.webpage_style = attributes[:'webpage_style'] end if attributes.key?(:'email_style') self.email_style = attributes[:'email_style'] end end |
Instance Attribute Details
#description ⇒ Object
Description of the campaign
25 26 27 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 25 def description @description end |
#email_style ⇒ Object
Returns the value of attribute email_style.
32 33 34 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 32 def email_style @email_style end |
#id ⇒ Object
Returns the value of attribute id.
19 20 21 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 19 def id @id end |
#name ⇒ Object
Name of the campaign
22 23 24 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 22 def name @name end |
#products ⇒ Object
List of IDs of products (different gift cards, charity, etc.) that are available in this campaign.
28 29 30 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 28 def products @products end |
#webpage_style ⇒ Object
Returns the value of attribute webpage_style.
30 31 32 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 30 def webpage_style @webpage_style end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 216 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Tremendous.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
47 48 49 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 47 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 35 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'description' => :'description', :'products' => :'products', :'webpage_style' => :'webpage_style', :'email_style' => :'email_style' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 192 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
64 65 66 67 68 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 64 def self.openapi_nullable Set.new([ :'description', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 60 61 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 52 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'description' => :'String', :'products' => :'Array<String>', :'webpage_style' => :'ListCampaigns200ResponseCampaignsInnerWebpageStyle', :'email_style' => :'ListCampaigns200ResponseCampaignsInnerEmailStyle' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
166 167 168 169 170 171 172 173 174 175 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 166 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && description == o.description && products == o.products && webpage_style == o.webpage_style && email_style == o.email_style end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 287 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
179 180 181 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 179 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
185 186 187 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 185 def hash [id, name, description, products, webpage_style, email_style].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 120 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/[A-Z0-9]{4,20}/) if !@id.nil? && @id !~ pattern invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.") end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @products.nil? invalid_properties.push('invalid value for "products", products cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
263 264 265 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 263 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 269 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
257 258 259 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 257 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
141 142 143 144 145 146 147 |
# File 'lib/tremendous/models/list_campaigns200_response_campaigns_inner.rb', line 141 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@id.nil? && @id !~ Regexp.new(/[A-Z0-9]{4,20}/) return false if @name.nil? return false if @products.nil? true end |