Class: Tremendous::Topup
- Inherits:
-
Object
- Object
- Tremendous::Topup
- Defined in:
- lib/tremendous/models/topup.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount in USD intended to be added to your organization’s balance.
-
#created_at ⇒ Object
Timestamp indicating when the topup object was created (when the request was made).
-
#fully_credited_at ⇒ Object
Timestamp indicating when the topup amount was fully credited to the balance.
-
#funding_source_id ⇒ Object
ID of the funding_source object used for this topup.
-
#id ⇒ Object
Unique identifier for the topup request.
-
#idempotency_key ⇒ Object
Idempotency key to prevent duplicate requests.
-
#processing_fee ⇒ Object
Amount of the processing fee for the topup (typically reserved for credit card topups).
-
#rejected_at ⇒ Object
Timestamp indicating when the topup was rejected.
-
#reversed_at ⇒ Object
Timestamp indicating when the topup was reversed.
-
#reversed_reason ⇒ Object
A sentence explaining why the topup was reversed.
-
#status ⇒ Object
Status of the topup <table> <thead> <tr> <th> Status </th> <th> Description </th> </tr> </thead> <tbody> <tr> <td>
created</td> <td> The topup is processing (and may be under review).
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Topup
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Topup
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/tremendous/models/topup.rb', line 108 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Tremendous::Topup` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Tremendous::Topup`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'processing_fee') self.processing_fee = attributes[:'processing_fee'] end if attributes.key?(:'funding_source_id') self.funding_source_id = attributes[:'funding_source_id'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'fully_credited_at') self.fully_credited_at = attributes[:'fully_credited_at'] end if attributes.key?(:'rejected_at') self.rejected_at = attributes[:'rejected_at'] end if attributes.key?(:'reversed_at') self.reversed_at = attributes[:'reversed_at'] end if attributes.key?(:'reversed_reason') self.reversed_reason = attributes[:'reversed_reason'] end if attributes.key?(:'idempotency_key') self.idempotency_key = attributes[:'idempotency_key'] end end |
Instance Attribute Details
#amount ⇒ Object
Amount in USD intended to be added to your organization’s balance.
22 23 24 |
# File 'lib/tremendous/models/topup.rb', line 22 def amount @amount end |
#created_at ⇒ Object
Timestamp indicating when the topup object was created (when the request was made).
34 35 36 |
# File 'lib/tremendous/models/topup.rb', line 34 def created_at @created_at end |
#fully_credited_at ⇒ Object
Timestamp indicating when the topup amount was fully credited to the balance.
37 38 39 |
# File 'lib/tremendous/models/topup.rb', line 37 def fully_credited_at @fully_credited_at end |
#funding_source_id ⇒ Object
ID of the funding_source object used for this topup.
28 29 30 |
# File 'lib/tremendous/models/topup.rb', line 28 def funding_source_id @funding_source_id end |
#id ⇒ Object
Unique identifier for the topup request.
19 20 21 |
# File 'lib/tremendous/models/topup.rb', line 19 def id @id end |
#idempotency_key ⇒ Object
Idempotency key to prevent duplicate requests.
49 50 51 |
# File 'lib/tremendous/models/topup.rb', line 49 def idempotency_key @idempotency_key end |
#processing_fee ⇒ Object
Amount of the processing fee for the topup (typically reserved for credit card topups).
25 26 27 |
# File 'lib/tremendous/models/topup.rb', line 25 def processing_fee @processing_fee end |
#rejected_at ⇒ Object
Timestamp indicating when the topup was rejected.
40 41 42 |
# File 'lib/tremendous/models/topup.rb', line 40 def rejected_at @rejected_at end |
#reversed_at ⇒ Object
Timestamp indicating when the topup was reversed.
43 44 45 |
# File 'lib/tremendous/models/topup.rb', line 43 def reversed_at @reversed_at end |
#reversed_reason ⇒ Object
A sentence explaining why the topup was reversed.
46 47 48 |
# File 'lib/tremendous/models/topup.rb', line 46 def reversed_reason @reversed_reason end |
#status ⇒ Object
Status of the topup <table> <thead> <tr> <th> Status </th> <th> Description </th> </tr> </thead> <tbody> <tr> <td> created </td> <td> The topup is processing (and may be under review). </td> </tr> <tr> <td> fully_credited </td> <td> The funds have been added to the balance. </td> </tr> <tr> <td> reversed </td> <td> The topup was credited, but then reversed due to a chargeback or ACH return. </td> </tr> <tr> <td> rejected </td> <td> The topup was rejected by an admin. </td> </tr> </tbody> </table>
31 32 33 |
# File 'lib/tremendous/models/topup.rb', line 31 def status @status end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/tremendous/models/topup.rb', line 239 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Tremendous.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
69 70 71 |
# File 'lib/tremendous/models/topup.rb', line 69 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
74 75 76 |
# File 'lib/tremendous/models/topup.rb', line 74 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/tremendous/models/topup.rb', line 52 def self.attribute_map { :'id' => :'id', :'amount' => :'amount', :'processing_fee' => :'processing_fee', :'funding_source_id' => :'funding_source_id', :'status' => :'status', :'created_at' => :'created_at', :'fully_credited_at' => :'fully_credited_at', :'rejected_at' => :'rejected_at', :'reversed_at' => :'reversed_at', :'reversed_reason' => :'reversed_reason', :'idempotency_key' => :'idempotency_key' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/tremendous/models/topup.rb', line 215 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
96 97 98 99 100 101 102 103 104 |
# File 'lib/tremendous/models/topup.rb', line 96 def self.openapi_nullable Set.new([ :'fully_credited_at', :'rejected_at', :'reversed_at', :'reversed_reason', :'idempotency_key' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/tremendous/models/topup.rb', line 79 def self.openapi_types { :'id' => :'String', :'amount' => :'Float', :'processing_fee' => :'Float', :'funding_source_id' => :'String', :'status' => :'String', :'created_at' => :'Time', :'fully_credited_at' => :'Time', :'rejected_at' => :'Time', :'reversed_at' => :'Time', :'reversed_reason' => :'String', :'idempotency_key' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/tremendous/models/topup.rb', line 184 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && amount == o.amount && processing_fee == o.processing_fee && funding_source_id == o.funding_source_id && status == o.status && created_at == o.created_at && fully_credited_at == o.fully_credited_at && rejected_at == o.rejected_at && reversed_at == o.reversed_at && reversed_reason == o.reversed_reason && idempotency_key == o.idempotency_key end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/tremendous/models/topup.rb', line 310 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
202 203 204 |
# File 'lib/tremendous/models/topup.rb', line 202 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
208 209 210 |
# File 'lib/tremendous/models/topup.rb', line 208 def hash [id, amount, processing_fee, funding_source_id, status, created_at, fully_credited_at, rejected_at, reversed_at, reversed_reason, idempotency_key].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
169 170 171 172 173 |
# File 'lib/tremendous/models/topup.rb', line 169 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
286 287 288 |
# File 'lib/tremendous/models/topup.rb', line 286 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/tremendous/models/topup.rb', line 292 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
280 281 282 |
# File 'lib/tremendous/models/topup.rb', line 280 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
177 178 179 180 |
# File 'lib/tremendous/models/topup.rb', line 177 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |